/*---------------------------------------------------------*/
/*                                                         */
/*   Turbo Vision 1.0                                      */
/*   TMemo class example                                   */
/*                                                         */
/*   Copyright (c) 1991 by Borland International           */
/*                                                         */
/*---------------------------------------------------------*/

#define Uses_TEvent
#define Uses_TDeskTop
#define Uses_TProgram
#define Uses_TApplication
#define Uses_TKeys
#define Uses_TRect
#define Uses_TMenuBar
#define Uses_TMenu
#define Uses_TMenuItem
#define Uses_TStatusDef
#define Uses_TStatusItem
#define Uses_TStatusLine
#define Uses_TDialog
#define Uses_TButton
#define Uses_TLabel
#define Uses_TMemo
#define Uses_TIndicator
#define Uses_TScrollBar
#include <tv.h>

#define BUFSIZE 512

const int cmNewDialog  = 200;

struct dialogData           // Structure for dialog data.
{
    ushort length;          // Length of text in TMemo buffer
    char buffer[BUFSIZE];   // Buffer for text from TMemo
};


//
// Application class
//
//  constructor, initMenuBar, handleEvent, dialog function, and memo buffer
//
class TMyApp : public TApplication
{
public:
    TMyApp() : TProgInit( initStatusLine, initMenuBar, initDeskTop )
        { memset(&memoBuf, 0, sizeof( dialogData ) ); }
    static TMenuBar *initMenuBar( TRect r );
    virtual void handleEvent( TEvent& event);
    void newDialog();
private:
    dialogData memoBuf;
};


//
// Subclass TDialog to encapsulate the creation of the dialog box.
//
class TMemoDialog : public TDialog
{
public:
    TMemoDialog(char *aTitle);
};


void TMyApp::handleEvent(TEvent& event)
{
    TApplication::handleEvent(event);   // Call parent handleEvent()
    if( event.what == evCommand )
        {
        switch( event.message.command )
            {
            case cmNewDialog:
                newDialog();            // Function to put up dialog box.
                break;
            default:
                return;                 // Don't clear events we don't handle.
            }
        clearEvent( event );            // clear event after handling.
        }
}

TMenuBar *TMyApp::initMenuBar( TRect r )
{
    r.b.y = r.a.y + 1;
    return new TMenuBar( r, new TMenu(
        *new TMenuItem( "E~x~it", cmQuit, kbAltX, hcNoContext, NULL,
         new TMenuItem( "~D~ialog", cmNewDialog, kbF2 )
        )));
}


void TMyApp::newDialog()
{
    TMemoDialog *pd = new TMemoDialog( "Sticky Note" );
    if( validView(pd) )                     // Make sure allocation ok.
        {
        pd->setData( &memoBuf );            // Restore old text (if any.)
        if( deskTop->execView(pd) == cmOK ) // Create modal dialog box.
            pd->getData( &memoBuf );        // Save text (if OK pressed.)
        destroy( pd );                      // Destroy dialog box.
        }
}


TMemoDialog::TMemoDialog(char *aTitle) :
    TDialog( TRect(0,0,52,16), aTitle ),
    TWindowInit( initFrame )
{
    TIndicator *ind = new TIndicator(TRect(2,14,39,15));
    TScrollBar *horz = new TScrollBar(TRect(16,14,39,15));
    TScrollBar *vert = new TScrollBar(TRect(39,2,40,14));
    TMemo *memo = new TMemo(TRect(2,2,39,14), horz, vert, ind, BUFSIZE);
    insert( ind );
    insert( vert );
    insert( horz );
    insert( memo );
    insert( new TLabel( TRect(2,1,12,2), "Memo Pad", memo) );

    insert( new TButton( TRect(40,5,50,7), "~O~K", cmOK, bfDefault ) );
    insert( new TButton( TRect(40,9,50,11), "~C~ancel", cmCancel, bfNormal ) );

    options |= ofCentered | ofFirstClick;
    selectNext( False );
}


int main()
{
    TMyApp myApp;
    myApp.run();
    return 0;
}
